@@ -1,4 +1,4 @@
-mod common;
+pub mod common;
 pub mod decimal;
 pub mod error;
 pub mod rate;
